@@ -1,9 +1,13 @@
 from django import template
+from django.template import Context, loader
+from django.template.loader import render_to_string
+from django.
 register = template.Library()
 
 from ..lib.manager import NavigationManager
 
 navigation_manager = NavigationManager()
+template_path = "navigation_bar.html"
 
 @register.tag
 def navigationbar ( parser, token ):
@@ -20,9 +24,14 @@ class NavigationBarNode ( template.Node ):
 	def render ( self, context ):
 		try :
 			bar = navigation_manager.get_bar( self.bar_name )
-			return bar
+
+			return render_to_string(template_path,{
+				"Bar"	: self.items,
+				"Name" : self.name
+			})
+
 		except :
-			return ""
+			return "-Bar %s Not Found-" % self.bar_name
 
 @register.tag
 def navigationbar_count ( parser, token = None):
